package com.ruoyi.system.service;

import com.ruoyi.system.entity.CommonEntity;
import com.ruoyi.system.entity.DragTable;

import java.util.List;

/**
 * 动态格Service接口
 * 
 * @author ruoyi
 * @date 2023-07-31
 */
public interface IDragTableService 
{
    /**
     * 查询动态格
     * 
     * @param tId 动态格主键
     * @return 动态格
     */
    public DragTable selectDragTableByTId(Long tId);

    /**
     * 查询动态格列表
     * 
     * @param dragTable 动态格
     * @return 动态格集合
     */
    public List<DragTable> selectDragTableList(DragTable dragTable);

    /**
     * 新增动态格
     * 
     * @param dragTable 动态格
     * @return 结果
     */
    public int insertDragTable(DragTable dragTable);

    /**
     * 修改动态格
     * 
     * @param dragTable 动态格
     * @return 结果
     */
    public int updateDragTable(DragTable dragTable);

    /**
     * 批量删除动态格
     * 
     * @param tIds 需要删除的动态格主键集合
     * @return 结果
     */
    public int deleteDragTableByTIds(Long[] tIds);

    /**
     * 删除动态格信息
     * 
     * @param tId 动态格主键
     * @return 结果
     */
    public int deleteDragTableByTId(Long tId);

    /**
     * 查询动态格
     *
     * @param sqlKey 唯一标识
     * @return 动态格
     */
    CommonEntity dragTableInfo(String sqlKey);
}
